@@ -1,8 +1,8 @@
 import pytest
 import plakativ
 import tempfile
-import fitz_old as fitz
-import fitz_old.utils as fitz_utils
+import fitz
+import fitz.utils as fitz_utils
 import os
 import math
 
